@@ -6,7 +6,7 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     RocsSimilarity, ParallelRocsSimilarity, PredictivePropertyComponent, SelectivityComponent, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
     NumRings, AZlogD74, HLMClint, SlogP, \
-    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20
+    RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -31,6 +31,7 @@ class ScoreComponentFactory:
             enum.MOLECULAR_WEIGHT: MolWeight,
             enum.TPSA: PSA,
             enum.NUM_ROTATABLE_BONDS: RotatableBonds,
+            enum.GRAPH_LENGTH: GraphLength,
             enum.NUM_HBD_LIPINSKI: HBD_Lipinski,
             enum.NUM_HBA_LIPINSKI: HBA_Lipinski,
             enum.NUM_RINGS: NumRings,
